@@ -256,7 +256,7 @@ def gql_query(api_root, input, output):  # pylint:disable=redefined-builtin
 
     if result.get("errors"):
         # raise exception when there's any root level errors
-        raise QctrlException(result["errors"])
+        raise QctrlException(result["errors"])  # pylint: disable=unsubscriptable-object
 
     _process_output(result, output)
 
